==> qcpufreq_0.3.2-1.tar.gz: qcpufreq-0.3.2/src/de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE" sourcelanguage="en_US">
<context>
    <name>HelpWindow</name>
    <message>
        <location filename="helpwindow.ui" line="14"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="helpwindow.cpp" line="56"/>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <location filename="helpwindow.cpp" line="56"/>
        <source>Cannot open help file!</source>
        <translation>Kann die Hilfe-Datei nicht öffnen!</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="mainwindow.cpp" line="147"/>
        <location filename="mainwindow.cpp" line="298"/>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="40"/>
        <source>Minimum CPU speed:</source>
        <translation>Min. CPU Frequenz:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="47"/>
        <location filename="mainwindow.ui" line="67"/>
        <location filename="mainwindow.ui" line="87"/>
        <location filename="mainwindow.ui" line="107"/>
        <location filename="mainwindow.cpp" line="175"/>
        <location filename="mainwindow.cpp" line="184"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="60"/>
        <source>Maximum CPU speed:</source>
        <translation>Max. CPU Frequenz:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="80"/>
        <source>Scaling governor:</source>
        <translation>Scaling Governor:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>CPU temperature:</source>
        <translation>CPU Temperatur:</translation>
    </message>
    <message utf8="true">
        <location filename="mainwindow.ui" line="126"/>
        <source>SmartReflex™:</source>
        <translation>SmartReflex™:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="139"/>
        <source>Enable</source>
        <oldsource>Disabled</oldsource>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="336"/>
        <source>Set maximum CPU frequency:</source>
        <translation>Maximale CPU Frequenz einstellen:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="364"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="373"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="378"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="147"/>
        <source>There seems to be a problem with your sudo setup!</source>
        <translation>Es liegt offenbar ein Problem bei der sudo Einrichtung vor!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="298"/>
        <source>Could not get information from /sys!</source>
        <translation>Konnte Informationen aus /sys nicht lesen!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="404"/>
        <source>SmartReflex support is known to be unstable on some devices and may cause random reboots.</source>
        <translation>SmartReflex kann auf einigen Geräten instabil sein und zu zufälligen Neustarts führen.</translation>
    </message>
</context>
</TS>

==> qcpufreq_0.3.4-1.tar.gz: qcpufreq-0.3.4/src/de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE" sourcelanguage="en_US">
<context>
    <name>HelpWindow</name>
    <message>
        <location filename="helpwindow.ui" line="14"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="helpwindow.cpp" line="56"/>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <location filename="helpwindow.cpp" line="56"/>
        <source>Cannot open help file!</source>
        <translation>Kann die Hilfe-Datei nicht öffnen!</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="mainwindow.cpp" line="162"/>
        <location filename="mainwindow.cpp" line="337"/>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="40"/>
        <source>Minimum CPU speed:</source>
        <translation>Min. CPU Frequenz:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="47"/>
        <location filename="mainwindow.ui" line="67"/>
        <location filename="mainwindow.ui" line="87"/>
        <location filename="mainwindow.ui" line="107"/>
        <location filename="mainwindow.cpp" line="190"/>
        <location filename="mainwindow.cpp" line="199"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="60"/>
        <source>Maximum CPU speed:</source>
        <translation>Max. CPU Frequenz:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="80"/>
        <source>Scaling governor:</source>
        <translation>Scaling Governor:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>CPU temperature:</source>
        <translation>CPU Temperatur:</translation>
    </message>
    <message utf8="true">
        <location filename="mainwindow.ui" line="126"/>
        <source>SmartReflex™:</source>
        <translation>SmartReflex™:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="139"/>
        <source>Enable</source>
        <oldsource>Disabled</oldsource>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="336"/>
        <source>Set maximum CPU frequency:</source>
        <translation>Maximale CPU Frequenz einstellen:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="364"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="374"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="379"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="387"/>
        <source>Enable overclocking</source>
        <translation>Aktiviere Übertakten</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <source>You need to enable overclocking in QCPUFreq&apos;s menu for setting frequencies above 600MHz!</source>
        <translation>Um Frequenzen über 600MHz freizuschalten, muss Overclocking im QCPUFreq Menü aktiviert werden!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="162"/>
        <source>There seems to be a problem with your sudo setup!</source>
        <translation>Es liegt offenbar ein Problem bei der sudo Einrichtung vor!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="337"/>
        <source>Could not get information from /sys!</source>
        <translation>Konnte Informationen aus /sys nicht lesen!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="440"/>
        <source>Please note that overclocking voids your warranty and may break your device! Be careful!</source>
        <translation>Bitte beachten Sie, dass Overclocking zu Garantieverlust führt und das Gerät beschädigen kann! Seien Sie vorsichtig!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="459"/>
        <source>SmartReflex support is known to be unstable on some devices and may cause random reboots.</source>
        <translation>SmartReflex kann auf einigen Geräten instabil sein und zu zufälligen Neustarts führen.</translation>
    </message>
</context>
</TS>
